pub struct HttpDependency {
pub name: String,
pub version_req: String,
pub url: Option<String>,
pub project_root: Option<PathBuf>,
}Expand description
An HTTP dependency config item.
This struct is used to represent an HTTP dependency from the config file.
Fields
name: StringThe name of the dependency (user-defined).
version_req: StringThe version requirement string (semver).
Example: >=1.9.3 || ^2.0.0
When no operator is used before the version number, it defaults to = which pins the
version.
url: Option<String>The URL to the dependency.
If omitted, the registry will be contacted to get the download URL for that dependency (by name).
project_root: Option<PathBuf>An optional relative path to the project’s root within the zip file.
The project root is where the soldeer.toml or foundry.toml resides. If no path is provided, then the zip’s root must contain a Soldeer config.
Implementations
Sourceimpl HttpDependency
impl HttpDependency
Sourcepub fn builder() -> HttpDependencyBuilder
pub fn builder() -> HttpDependencyBuilder
Create an instance of HttpDependency using the builder syntax