pub struct InstallMonitoring {
pub logs: UnboundedReceiver<String>,
pub versions: UnboundedReceiver<DependencyName>,
pub downloads: UnboundedReceiver<DependencyName>,
pub unzip: UnboundedReceiver<DependencyName>,
pub subdependencies: UnboundedReceiver<DependencyName>,
pub integrity: UnboundedReceiver<DependencyName>,
}Expand description
Collection of channels to monitor the progress of the install process.
Fields
logs: UnboundedReceiver<String>Channel to receive install progress logs.
versions: UnboundedReceiver<DependencyName>Progress for calls to the API to retrieve the packages versions.
downloads: UnboundedReceiver<DependencyName>Progress for downloading the dependencies.
unzip: UnboundedReceiver<DependencyName>Progress for unzipping the downloaded files.
subdependencies: UnboundedReceiver<DependencyName>Progress for installing subdependencies.
integrity: UnboundedReceiver<DependencyName>Progress for checking the integrity of the installed dependencies.