#[non_exhaustive]pub enum LockEntry {
Http(HttpLockEntry),
Git(GitLockEntry),
Private(PrivateLockEntry),
}Expand description
A lock entry for a dependency.
A builder should be used to create the underlying HttpLockEntry or GitLockEntry and then
converted into this type with .into().
Examples
let dep: LockEntry = HttpLockEntry::builder()
.name("my-dep")
.version("1.2.3")
.url("https://...")
.checksum("dead")
.integrity("beef")
.build()
.into();Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Http(HttpLockEntry)
A lock entry for an HTTP dependency.
Git(GitLockEntry)
A lock entry for a git dependency.
Private(PrivateLockEntry)
A lock entry for a git dependency.
Implementations
Sourceimpl LockEntry
impl LockEntry
Sourcepub fn install_path(&self, deps: impl AsRef<Path>) -> PathBuf
pub fn install_path(&self, deps: impl AsRef<Path>) -> PathBuf
The install path of the dependency.
Sourcepub fn as_http(&self) -> Option<&HttpLockEntry>
pub fn as_http(&self) -> Option<&HttpLockEntry>
Get the underlying HttpLockEntry if this is an HTTP lock entry.
Sourcepub fn as_git(&self) -> Option<&GitLockEntry>
pub fn as_git(&self) -> Option<&GitLockEntry>
Get the underlying GitLockEntry if this is a git lock entry.
Sourcepub fn as_private(&self) -> Option<&PrivateLockEntry>
pub fn as_private(&self) -> Option<&PrivateLockEntry>
Get the underlying PrivateLockEntry if this is a private package lock entry.