pub struct Lockfile { /* private fields */ }Expand description
A lockfile handler that keeps track of the dependencies and their current state.
Implementations
Sourceimpl Lockfile
impl Lockfile
Sourcepub fn new(project_root: &Path) -> Self
pub fn new(project_root: &Path) -> Self
Create a new Lockfile instance.
project_root is the absolute path to the project root.
You will need to call Lockfile::read to load the lockfile.
Sourcepub fn read(&mut self) -> Result<()>
pub fn read(&mut self) -> Result<()>
Loads the lockfile from the project root.
Throws an error if the lockfile does not exist.
Sourcepub fn get(&self, path: &Path) -> Option<&DepIdentifier>
pub fn get(&self, path: &Path) -> Option<&DepIdentifier>
Get the DepIdentifier for a submodule at a given path.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&PathBuf, &DepIdentifier)>
pub fn iter(&self) -> impl Iterator<Item = (&PathBuf, &DepIdentifier)>
Returns an iterator over the lockfile.
pub fn exists(&self) -> bool