#[non_exhaustive]pub struct HttpLockEntry {
pub name: String,
pub version: String,
pub url: String,
pub checksum: String,
pub integrity: String,
}Expand description
A lock entry for an HTTP dependency.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the dependency.
version: StringThe resolved version of the dependency (not necessarily matches the version requirement of the dependency).
If the version req is a semver range, then this will be the exact version that was resolved.
url: StringThe URL from where the dependency was downloaded.
checksum: StringThe checksum of the downloaded zip file.
integrity: StringThe integrity hash of the downloaded zip file after extraction.
Implementations
Sourceimpl HttpLockEntry
impl HttpLockEntry
Sourcepub fn builder() -> HttpLockEntryBuilder
pub fn builder() -> HttpLockEntryBuilder
Create an instance of HttpLockEntry using the builder syntax