pub struct HttpLockEntryBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> HttpLockEntryBuilder<S>
impl<S: State> HttpLockEntryBuilder<S>
Sourcepub fn build(self) -> HttpLockEntrywhere
S: IsComplete,
pub fn build(self) -> HttpLockEntrywhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn name(self, value: impl Into<String>) -> HttpLockEntryBuilder<SetName<S>>where
S::Name: IsUnset,
pub fn name(self, value: impl Into<String>) -> HttpLockEntryBuilder<SetName<S>>where
S::Name: IsUnset,
Required.
The name of the dependency.
Sourcepub fn version(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetVersion<S>>where
S::Version: IsUnset,
Required.
The resolved version of the dependency (not necessarily matches the version requirement of the dependency).
If the version req is a semver range, then this will be the exact version that was resolved.
Sourcepub fn url(self, value: impl Into<String>) -> HttpLockEntryBuilder<SetUrl<S>>where
S::Url: IsUnset,
pub fn url(self, value: impl Into<String>) -> HttpLockEntryBuilder<SetUrl<S>>where
S::Url: IsUnset,
Required.
The URL from where the dependency was downloaded.
Sourcepub fn checksum(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetChecksum<S>>where
S::Checksum: IsUnset,
pub fn checksum(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetChecksum<S>>where
S::Checksum: IsUnset,
Required.
The checksum of the downloaded zip file.
Sourcepub fn integrity(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetIntegrity<S>>where
S::Integrity: IsUnset,
pub fn integrity(
self,
value: impl Into<String>,
) -> HttpLockEntryBuilder<SetIntegrity<S>>where
S::Integrity: IsUnset,
Required.
The integrity hash of the downloaded zip file after extraction.