#[non_exhaustive]pub struct PrivateLockEntry {
pub name: String,
pub version: String,
pub checksum: String,
pub integrity: String,
}Expand description
A lock entry for a private dependency.
The link is not stored in the lockfile as it must be fetched from the registry with a valid token before each download.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the dependency.
version: StringThe resolved version of the dependency (not necessarily matches the version requirement of the dependency).
If the version req is a semver range, then this will be the exact version that was resolved.
checksum: StringThe checksum of the downloaded zip file.
integrity: StringThe integrity hash of the downloaded zip file after extraction.
Implementations
Sourceimpl PrivateLockEntry
impl PrivateLockEntry
Sourcepub fn builder() -> PrivateLockEntryBuilder
pub fn builder() -> PrivateLockEntryBuilder
Create an instance of PrivateLockEntry using the builder syntax