pub struct InstallProgress {
pub logs: UnboundedSender<String>,
pub versions: UnboundedSender<DependencyName>,
pub downloads: UnboundedSender<DependencyName>,
pub unzip: UnboundedSender<DependencyName>,
pub subdependencies: UnboundedSender<DependencyName>,
pub integrity: UnboundedSender<DependencyName>,
}Expand description
Collection of channels to notify the caller of the install progress.
Fields
logs: UnboundedSender<String>Channel to send messages to be logged to the user.
versions: UnboundedSender<DependencyName>Progress for calls to the API to retrieve the packages versions.
downloads: UnboundedSender<DependencyName>Progress for downloading the dependencies.
unzip: UnboundedSender<DependencyName>Progress for unzipping the downloaded files.
subdependencies: UnboundedSender<DependencyName>Progress for installing subdependencies.
integrity: UnboundedSender<DependencyName>Progress for checking the integrity of the installed dependencies.
Implementations
Sourceimpl InstallProgress
impl InstallProgress
Sourcepub fn new() -> (Self, InstallMonitoring)
pub fn new() -> (Self, InstallMonitoring)
Create a new install progress tracker, with a receiving half (InstallMonitoring) and a sending half (InstallProgress).
Sourcepub fn update_all(&self, dependency_name: DependencyName)
pub fn update_all(&self, dependency_name: DependencyName)
Advance all progress trackers at once, passing the dependency name.